@@ -3,7 +3,7 @@ from operator import attrgetter
 from django import template
 from django.conf import settings
 from django.http import Http404
-from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext_lazy as _
 
 register = template.Library()
 
